@@ -13,7 +13,7 @@ use std::rc::Rc;
 /// but normally you create a [GrammarRule]
 /// by using a [GrammarBuilder](crate::grammar::GrammarBuilder).
 #[derive(Clone)]
-pub(crate) struct GrammarRule {
+pub struct GrammarRule {
     pub(crate) name:           Rc<String>,
     pub(crate) disambiguation: Option<Disambiguation>,
     pub(crate) productions:    Vec<Rc<Production>>,
@@ -29,7 +29,7 @@ impl std::fmt::Display for GrammarRule {
                 .iter()
                 .map(|production| production.to_string())
                 .collect::<Vec<String>>()
-                .join(" | ")
+                .join("\n    | ")
         )
     }
 }
