@@ -8,22 +8,37 @@ use crate::grammar::Symbol;
 use crate::grammar::START_RULE_NAME;
 use crate::lexer::Lexeme;
 use crate::parser::tree::build;
+use crate::parser::ParseError;
 use crate::parser::ParserColumn;
 use crate::parser::ParserState;
 use crate::parser::Tree;
 use std::collections::HashSet;
 use std::rc::Rc;
 
-fn predict(column: &mut ParserColumn, rule: &GrammarRule) {
+fn predict(
+    columns: &mut Vec<ParserColumn>,
+    column_index: usize,
+    rule: &GrammarRule,
+) {
     for production in &rule.productions {
+        if column_index + 1 < columns.len()
+            && !production.target_lexemes.borrow().is_empty()
+            && !production
+                .target_lexemes
+                .borrow()
+                .contains(&columns[column_index + 1].kind)
+        {
+            continue;
+        }
+
         let new_state = ParserState {
             name:         rule.name.clone(),
             production:   production.clone(),
             dot_index:    0,
-            start_column: column.index,
+            start_column: column_index,
             end_column:   usize::MAX,
         };
-        column.add(new_state);
+        columns[column_index].add(new_state);
     }
 }
 
@@ -85,16 +100,42 @@ fn complete(
 pub fn parse(
     grammar: &Grammar,
     lexemes: &[Lexeme],
-) -> Result<Vec<Rc<Tree>>, String> {
-    let columns: Vec<ParserColumn> = earley(grammar, lexemes);
+) -> Result<Vec<Rc<Tree>>, ParseError> {
+    let mut columns: Vec<ParserColumn> = earley(grammar, lexemes);
 
+    let mut parent = None;
     for state in &columns.last().unwrap().states {
         if *state.name == START_RULE_NAME && state.completed() {
-            return Ok(build(grammar, lexemes, &columns, state));
+            parent = Some(state.clone());
+            break;
         }
     }
 
-    Err(String::new())
+    if let Some(state) = parent {
+        for column in columns.iter_mut() {
+            column.states = column
+                .states
+                .iter()
+                .filter(|state| state.completed())
+                .cloned()
+                .collect();
+        }
+
+        Ok(build(grammar, lexemes, &columns, &state))
+    } else if lexemes.is_empty() {
+        Err(ParseError { at: None, states: columns[0].states.clone() })
+    } else {
+        let column = columns
+            .iter()
+            .rev()
+            .find(|column| !column.states.is_empty())
+            .unwrap();
+
+        Err(ParseError {
+            at:     lexemes.get(column.index.overflowing_sub(1).0).cloned(),
+            states: column.states.clone(),
+        })
+    }
 }
 
 /// Parse the provided [Lexemes](Lexeme) with the given [Grammar]
@@ -144,7 +185,7 @@ pub fn earley(grammar: &Grammar, lexemes: &[Lexeme]) -> Vec<ParserColumn> {
                     Symbol::Rule(name) => {
                         if !predicted_names.contains(&name) {
                             let rule = grammar.rules.get(&name).unwrap();
-                            predict(&mut columns[column_index], rule);
+                            predict(&mut columns, column_index, rule);
                             predicted_names.insert(name);
                         }
                     }
@@ -163,15 +204,6 @@ pub fn earley(grammar: &Grammar, lexemes: &[Lexeme]) -> Vec<ParserColumn> {
         }
     }
 
-    for column in columns.iter_mut() {
-        column.states = column
-            .states
-            .iter()
-            .filter(|state| state.completed())
-            .cloned()
-            .collect();
-    }
-
     // println!();
     // println!("Columns:");
     // for (column_index, column) in columns.iter().enumerate() {
