@@ -11,7 +11,7 @@ pub mod smallest;
 fn ambiguous_integer_addition() {
     run(
         "ambiguous_integer_addition",
-        &ambiguous_integer_addition::lexer::lexer(),
+        &ambiguous_integer_addition::lexer::lexer_rules(),
         &ambiguous_integer_addition::grammar::grammar(),
     );
 }
@@ -20,7 +20,7 @@ fn ambiguous_integer_addition() {
 fn javascript_string_interpolation() {
     run(
         "javascript_string_interpolation",
-        &javascript_string_interpolation::lexer::lexer(),
+        &javascript_string_interpolation::lexer::lexer_rules(),
         &javascript_string_interpolation::grammar::grammar(),
     );
 }
@@ -29,27 +29,31 @@ fn javascript_string_interpolation() {
 fn integer_addition() {
     run(
         "integer_addition",
-        &integer_addition::lexer::lexer(),
+        &integer_addition::lexer::lexer_rules(),
         &integer_addition::grammar::grammar(),
     );
 }
 
 #[test]
 fn language_nix() {
-    let lexer = santiago::languages::nix::lexer_rules();
-    let grammar = santiago::languages::nix::grammar_rules(&lexer);
+    let lexer_rules = santiago::languages::nix::lexer_rules();
+    let grammar = santiago::languages::nix::grammar();
 
-    run("language_nix", &lexer, &grammar);
+    run("language_nix", &lexer_rules, &grammar);
 }
 
 #[test]
 fn smallest() {
-    run("smallest", &smallest::lexer::lexer(), &smallest::grammar::grammar());
+    run(
+        "smallest",
+        &smallest::lexer::lexer_rules(),
+        &smallest::grammar::grammar(),
+    );
 }
 
 fn run(
     name: &str,
-    lexer_rules: &[santiago::lexer::LexerRule],
+    lexer_rules: &santiago::lexer::LexerRules,
     grammar: &santiago::grammar::Grammar,
 ) {
     use std::io::Write;
@@ -74,13 +78,14 @@ fn run(
             .trim_end_matches('\n')
             .to_string();
 
-        let lexemes = santiago::lexer::lex(lexer_rules, &input);
+        let lexemes = santiago::lexer::lex(lexer_rules, &input).unwrap();
         let lexemes_str: String = lexemes
             .iter()
             .map(santiago::lexer::Lexeme::to_string)
             .collect::<Vec<String>>()
             .join("\n");
 
+        #[cfg(not(tarpaulin))]
         if should_update {
             std::fs::File::create(&path_lexemes)
                 .unwrap()
@@ -95,6 +100,7 @@ fn run(
             .collect::<Vec<String>>()
             .join("\n");
 
+        #[cfg(not(tarpaulin))]
         if should_update {
             std::fs::File::create(&path_earley)
                 .unwrap()
@@ -111,6 +117,7 @@ fn run(
             .collect::<Vec<&str>>()
             .join("\n");
 
+        #[cfg(not(tarpaulin))]
         if should_update {
             std::fs::File::create(&path_forest)
                 .unwrap()
